@@ -20,7 +20,6 @@ import glance_store
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
-from oslo_utils import encodeutils
 import webob
 
 from glance.api import policy
@@ -82,7 +81,8 @@ class ImageMembersController(object):
         # NOTE(abhishekk): Ownership check only needs to performed while
         # adding new members to image
         owner = image.owner
-        if not CONF.enforce_secure_rbac and not context.is_admin:
+        if not (CONF.oslo_policy.enforce_new_defaults or
+                CONF.oslo_policy.enforce_scope) and not context.is_admin:
             if ownership_check == 'create':
                 if owner is None or owner != context.owner:
                     message = _("You are not permitted to create image "
@@ -178,7 +178,7 @@ class ImageMembersController(object):
         except exception.ImageMemberLimitExceeded as e:
             msg = (_("Image member limit exceeded for image %(id)s: %(e)s:")
                    % {"id": image_id,
-                      "e": encodeutils.exception_to_unicode(e)})
+                      "e": e})
             LOG.warning(msg)
             raise webob.exc.HTTPRequestEntityTooLarge(explanation=msg)
 
@@ -227,8 +227,7 @@ class ImageMembersController(object):
             LOG.warning(msg)
             raise webob.exc.HTTPForbidden(explanation=msg)
         except ValueError as e:
-            msg = (_("Incorrect request: %s")
-                   % encodeutils.exception_to_unicode(e))
+            msg = (_("Incorrect request: %s") % e)
             LOG.warning(msg)
             raise webob.exc.HTTPBadRequest(explanation=msg)
 
