@@ -16,17 +16,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client as http
 import os
 import sys
+import urllib.parse as urlparse
 
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
-from oslo_utils import encodeutils
 from oslo_utils import uuidutils
-import six
-from six.moves import http_client as http
-import six.moves.urllib.parse as urlparse
 from webob import exc
 
 from glance.common import config
@@ -117,8 +115,9 @@ class ImageService(object):
     def __init__(self, conn, auth_token):
         """Initialize the ImageService.
 
-        conn: a http_client.HTTPConnection to the glance server
-        auth_token: authentication token to pass in the x-auth-token header
+        :param conn: a http.client.HTTPConnection to the glance server
+        :param auth_token: authentication token to pass in the x-auth-token
+            header
         """
         self.auth_token = auth_token
         self.conn = conn
@@ -133,7 +132,7 @@ class ImageService(object):
         body: body to send with the request
         ignore_result_body: the body of the result will be ignored
 
-        Returns: a http_client response object
+        :returns: A http.client response object
         """
         if self.auth_token:
             headers.setdefault('x-auth-token', self.auth_token)
@@ -178,7 +177,7 @@ class ImageService(object):
 
         if ignore_result_body:
             # NOTE: because we are pipelining requests through a single HTTP
-            # connection, http_client requires that we read the response body
+            # connection, http.client requires that we read the response body
             # before we can make another request. If the caller knows they
             # don't care about the body, they can ask us to do that for them.
             response.read()
@@ -211,7 +210,7 @@ class ImageService(object):
 
         image_uuid: the id of an image
 
-        Returns: a http_client Response object where the body is the image.
+        :returns: a http.client Response object where the body is the image.
         """
         url = '/v1/images/%s' % image_uuid
         return self._http_request('GET', url, {}, '')
@@ -394,11 +393,7 @@ def replication_dump(options, args):
                       'data_filename': data_filename})
 
             # Dump glance information
-            if six.PY3:
-                f = open(data_path, 'w', encoding='utf-8')
-            else:
-                f = open(data_path, 'w')
-            with f:
+            with open(data_path, 'w', encoding='utf-8') as f:
                 f.write(jsonutils.dumps(image))
 
             if image['status'] == 'active' and not options.metaonly:
@@ -512,8 +507,10 @@ def replication_load(options, args):
                         _check_upload_response_headers(headers, body)
                         updated.append(meta['id'])
                     except exc.HTTPConflict:
-                        LOG.error(_LE(IMAGE_ALREADY_PRESENT_MESSAGE)
-                                  % image_uuid)  # noqa
+                        # NOTE(tkajinam): noqa does not work with multi-line,
+                        # so split this interpolation to a separate line
+                        msg = _LE(IMAGE_ALREADY_PRESENT_MESSAGE) % image_uuid
+                        LOG.error(msg)
 
     return updated
 
@@ -636,24 +633,24 @@ def replication_compare(options, args):
 
             for key in image:
                 if image[key] != headers.get(key):
-                    LOG.warn(_LW('%(image_id)s: field %(key)s differs '
-                                 '(source is %(source_value)s, destination '
-                                 'is %(target_value)s)')
-                             % {'image_id': image['id'],
-                                'key': key,
-                                'source_value': image[key],
-                                'target_value': headers.get(key,
-                                                            'undefined')})
+                    LOG.warning(_LW('%(image_id)s: field %(key)s differs '
+                                    '(source is %(source_value)s, destination '
+                                    'is %(target_value)s)'),
+                                {'image_id': image['id'],
+                                 'key': key,
+                                 'source_value': image[key],
+                                 'target_value': headers.get(key,
+                                                             'undefined')})
                     differences[image['id']] = 'diff'
                 else:
                     LOG.debug('%(image_id)s is identical',
                               {'image_id': image['id']})
 
         elif image['status'] == 'active':
-            LOG.warn(_LW('Image %(image_id)s ("%(image_name)s") '
-                     'entirely missing from the destination')
-                     % {'image_id': image['id'],
-                        'image_name': image.get('name', '--unnamed')})
+            LOG.warning(_LW('Image %(image_id)s ("%(image_name)s") '
+                            'entirely missing from the destination'),
+                        {'image_id': image['id'],
+                         'image_name': image.get('name', '--unnamed')})
             differences[image['id']] = 'missing'
 
     return differences
@@ -737,7 +734,7 @@ def main():
     try:
         config.parse_args()
     except RuntimeError as e:
-        sys.exit("ERROR: %s" % encodeutils.exception_to_unicode(e))
+        sys.exit("ERROR: %s" % e)
     except SystemExit:
         sys.exit("Please specify one command")
 
@@ -754,10 +751,10 @@ def main():
         command(CONF, CONF.args)
     except TypeError as e:
         LOG.error(_LE(command.__doc__) % {'prog': command.__name__})  # noqa
-        sys.exit("ERROR: %s" % encodeutils.exception_to_unicode(e))
+        sys.exit("ERROR: %s" % e)
     except ValueError as e:
         LOG.error(_LE(command.__doc__) % {'prog': command.__name__})  # noqa
-        sys.exit("ERROR: %s" % encodeutils.exception_to_unicode(e))
+        sys.exit("ERROR: %s" % e)
 
 
 if __name__ == '__main__':
