@@ -22,15 +22,12 @@ System-level utilities and helper functions.
 
 import errno
 
-try:
-    from eventlet import sleep
-except ImportError:
-    from time import sleep
 from eventlet.green import socket
 
 import functools
 import os
 import re
+from time import sleep
 import urllib
 
 import glance_store
@@ -39,11 +36,10 @@ from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import netutils
 from oslo_utils import strutils
+from oslo_utils import timeutils as oslo_timeutils
 from webob import exc
 
 from glance.common import exception
-from glance.common import location_strategy
-from glance.common import timeutils
 from glance.common import wsgi
 from glance.i18n import _, _LE, _LW
 
@@ -578,7 +574,7 @@ def split_filter_op(expression):
         # not be partitioned, and a default operator of eq should be
         # assumed.
         try:
-            timeutils.parse_isotime(expression)
+            oslo_timeutils.parse_isotime(expression)
             op = 'eq'
             threshold = expression
         except ValueError:
@@ -717,20 +713,19 @@ def get_stores_from_request(req, body):
 
 def sort_image_locations(locations):
     if not CONF.enabled_backends:
-        return location_strategy.get_ordered_locations(locations)
+        return locations
 
     def get_store_weight(location):
         store_id = location['metadata'].get('store')
         if not store_id:
             return 0
         try:
-            store = glance_store.get_store_from_store_identifier(store_id)
+            return glance_store.get_store_weight(store_id)
         except glance_store.exceptions.UnknownScheme:
             msg = (_LW("Unable to find store '%s', returning "
                        "default weight '0'") % store_id)
             LOG.warning(msg)
             return 0
-        return store.weight if store is not None else 0
 
     sorted_locations = sorted(locations, key=get_store_weight, reverse=True)
     scrubbed = []
@@ -739,3 +734,14 @@ def sort_image_locations(locations):
 
     LOG.debug(('Sorted locations: %s'), scrubbed)
     return sorted_locations
+
+
+def is_http_store_configured(url):
+    if not url.startswith("http"):
+        return False
+
+    enabled_backends = CONF.enabled_backends
+    if enabled_backends:
+        return 'http' in enabled_backends.values()
+    else:
+        return 'http' in CONF.glance_store.stores
