@@ -13,22 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
+import builtins
 
 import eventlet
-# NOTE(jokke): As per the eventlet commit
-# b756447bab51046dfc6f1e0e299cc997ab343701 there's circular import happening
-# which can be solved making sure the hubs are properly and fully imported
-# before calling monkey_patch(). This is solved in eventlet 0.22.0 but we
-# need to address it before that is widely used around.
-eventlet.hubs.get_hub()
-
-if os.name == 'nt':
-    # eventlet monkey patching the os module causes subprocess.Popen to fail
-    # on Windows when using pipes due to missing non-blocking IO support.
-    eventlet.patcher.monkey_patch(os=False)
-else:
-    eventlet.patcher.monkey_patch()
+eventlet.patcher.monkey_patch()
 
 import glance.async_
 # NOTE(danms): Default to eventlet threading for tests
@@ -36,8 +24,7 @@ glance.async_.set_threadpool_model('eventlet')
 
 # See http://code.google.com/p/python-nose/issues/detail?id=373
 # The code below enables tests to work with i18n _() blocks
-import six.moves.builtins as __builtin__
-setattr(__builtin__, '_', lambda x: x)
+setattr(builtins, '_', lambda x: x)
 
 # Set up logging to output debugging
 import logging
