@@ -16,7 +16,6 @@
 import http.client as http
 
 from oslo_serialization import jsonutils
-import requests
 
 from glance.tests.functional.v2 import metadef_base
 
@@ -25,61 +24,55 @@ class TestMetadefResourceTypes(metadef_base.MetadefFunctionalTestBase):
 
     def setUp(self):
         super(TestMetadefResourceTypes, self).setUp()
-        self.cleanup()
-        self.api_server.deployment_flavor = 'noauth'
-        self.start_servers(**self.__dict__.copy())
+        self.start_server(enable_cache=False)
 
     def test_metadef_resource_types_lifecycle(self):
         # Namespace should not exist
-        path = self._url('/v2/metadefs/namespaces/MyNamespace')
-        response = requests.get(path, headers=self._headers())
+        path = '/v2/metadefs/namespaces/MyNamespace'
+        response = self.api_get(path, headers=self._headers())
         self.assertEqual(http.NOT_FOUND, response.status_code)
 
         # Create a namespace
-        path = self._url('/v2/metadefs/namespaces')
+        path = '/v2/metadefs/namespaces'
         headers = self._headers({'content-type': 'application/json'})
         namespace_name = 'MyNamespace'
-        data = jsonutils.dumps({
+        data = {
             "namespace": namespace_name,
             "display_name": "My User Friendly Namespace",
             "description": "My description",
             "visibility": "public",
             "protected": False,
             "owner": "The Test Owner"
-        })
-        response = requests.post(path, headers=headers, data=data)
+        }
+        response = self.api_post(path, headers=headers, json=data)
         self.assertEqual(http.CREATED, response.status_code)
 
         # Resource type should not exist
-        path = self._url('/v2/metadefs/namespaces/%s/resource_types' %
-                         (namespace_name))
-        response = requests.get(path, headers=self._headers())
+        path = '/v2/metadefs/namespaces/%s/resource_types' % (namespace_name)
+        response = self.api_get(path, headers=self._headers())
         metadef_resource_type = jsonutils.loads(response.text)
         self.assertEqual(
             0, len(metadef_resource_type['resource_type_associations']))
 
         # Create a resource type
-        path = self._url('/v2/metadefs/namespaces/MyNamespace/resource_types')
+        path = '/v2/metadefs/namespaces/MyNamespace/resource_types'
         headers = self._headers({'content-type': 'application/json'})
         metadef_resource_type_name = "resource_type1"
-        data = jsonutils.dumps(
-            {
-                "name": "resource_type1",
-                "prefix": "hw_",
-                "properties_target": "image",
-            }
-        )
-        response = requests.post(path, headers=headers, data=data)
+        data = {
+            "name": "resource_type1",
+            "prefix": "hw_",
+            "properties_target": "image",
+        }
+        response = self.api_post(path, headers=headers, json=data)
         self.assertEqual(http.CREATED, response.status_code)
 
         # Attempt to insert a duplicate
-        response = requests.post(path, headers=headers, data=data)
+        response = self.api_post(path, headers=headers, json=data)
         self.assertEqual(http.CONFLICT, response.status_code)
 
         # Get the metadef resource type created above
-        path = self._url('/v2/metadefs/namespaces/%s/resource_types' %
-                         (namespace_name))
-        response = requests.get(path,
+        path = '/v2/metadefs/namespaces/%s/resource_types' % (namespace_name)
+        response = self.api_get(path,
                                 headers=self._headers())
         self.assertEqual(http.OK, response.status_code)
         metadef_resource_type = jsonutils.loads(response.text)
@@ -112,21 +105,20 @@ class TestMetadefResourceTypes(metadef_base.MetadefFunctionalTestBase):
             u'properties_target',
         ])
         for key, value in expected_metadef_resource_types.items():
-            if(key in checked_values):
+            if key in checked_values:
                 self.assertEqual(
                     resource_type['resource_type_associations'][0][key],
                     value, key)
 
         # Deassociate of metadef resource type resource_type1
-        path = self._url('/v2/metadefs/namespaces/%s/resource_types/%s' %
-                         (namespace_name, metadef_resource_type_name))
-        response = requests.delete(path, headers=self._headers())
+        path = '/v2/metadefs/namespaces/%s/resource_types/%s' % (
+            namespace_name, metadef_resource_type_name)
+        response = self.api_delete(path, headers=self._headers())
         self.assertEqual(http.NO_CONTENT, response.status_code)
 
         # resource_type1 should not exist
-        path = self._url('/v2/metadefs/namespaces/%s/resource_types' %
-                         (namespace_name))
-        response = requests.get(path, headers=self._headers())
+        path = '/v2/metadefs/namespaces/%s/resource_types' % (namespace_name)
+        response = self.api_get(path, headers=self._headers())
         metadef_resource_type = jsonutils.loads(response.text)
         self.assertEqual(
             0, len(metadef_resource_type['resource_type_associations']))
@@ -140,11 +132,11 @@ class TestMetadefResourceTypes(metadef_base.MetadefFunctionalTestBase):
                 "prefix": "hw_",
                 "properties_target": "image"
             }
-            path = self._url('/v2/metadefs/namespaces/%s/resource_types' %
-                             (namespace['namespace']))
-            response = requests.post(path, headers=headers, json=data)
+            path = ('/v2/metadefs/namespaces/%s/'
+                    'resource_types') % (namespace['namespace'])
+            response = self.api_post(path, headers=headers, json=data)
             self.assertEqual(http.CREATED, response.status_code)
-            rs_type = response.json()
+            rs_type = jsonutils.loads(response.text)
             resource_type = dict()
             resource_type[namespace['namespace']] = rs_type['name']
             resource_types.append(resource_type)
@@ -153,7 +145,7 @@ class TestMetadefResourceTypes(metadef_base.MetadefFunctionalTestBase):
 
     def test_role_base_metadef_resource_types_lifecycle(self):
         # Create public and private namespaces for tenant1 and tenant2
-        path = self._url('/v2/metadefs/namespaces')
+        path = '/v2/metadefs/namespaces'
         headers = self._headers({'content-type': 'application/json'})
         tenant1_namespaces = []
         tenant2_namespaces = []
@@ -169,6 +161,7 @@ class TestMetadefResourceTypes(metadef_base.MetadefFunctionalTestBase):
                 }
                 namespace = self.create_namespace(path, headers,
                                                   namespace_data)
+                namespace = jsonutils.loads(namespace.text)
                 self.assertNamespacesEqual(namespace, namespace_data)
                 if tenant == self.tenant1:
                     tenant1_namespaces.append(namespace)
@@ -185,9 +178,9 @@ class TestMetadefResourceTypes(metadef_base.MetadefFunctionalTestBase):
             headers = self._headers({'X-Tenant-Id': tenant,
                                      'X-Roles': 'reader,member'})
             for namespace in namespaces:
-                path = self._url('/v2/metadefs/namespaces/%s/resource_types' %
-                                 (namespace['namespace']))
-                response = requests.get(path, headers=headers)
+                path = ('/v2/metadefs/namespaces/%s/'
+                        'resource_types') % (namespace['namespace'])
+                response = self.api_get(path, headers=headers)
                 if namespace['visibility'] == 'public':
                     self.assertEqual(http.OK, response.status_code)
                 else:
@@ -195,12 +188,12 @@ class TestMetadefResourceTypes(metadef_base.MetadefFunctionalTestBase):
 
         def _check_resource_types(tenant, total_rs_types):
             # Resource types are visible across tenants for all users
-            path = self._url('/v2/metadefs/resource_types')
+            path = '/v2/metadefs/resource_types'
             headers = self._headers({'X-Tenant-Id': tenant,
                                      'X-Roles': 'reader,member'})
-            response = requests.get(path, headers=headers)
+            response = self.api_get(path, headers=headers)
             self.assertEqual(http.OK, response.status_code)
-            metadef_resource_type = response.json()
+            metadef_resource_type = jsonutils.loads(response.text)
 
             # The resource types list count should be same as the total
             # resource types created across the tenants.
@@ -227,10 +220,9 @@ class TestMetadefResourceTypes(metadef_base.MetadefFunctionalTestBase):
         # Disassociate resource type should not be allowed to non admin role
         for resource_type in total_resource_types:
             for namespace, rs_type in resource_type.items():
-                path = \
-                    self._url('/v2/metadefs/namespaces/%s/resource_types/%s' %
-                              (namespace, rs_type))
-                response = requests.delete(
+                path = '/v2/metadefs/namespaces/%s/resource_types/%s' % (
+                    namespace, rs_type)
+                response = self.api_delete(
                     path, headers=self._headers({
                         'X-Roles': 'reader,member',
                         'X-Tenant-Id': namespace.split('_')[0]
@@ -241,19 +233,17 @@ class TestMetadefResourceTypes(metadef_base.MetadefFunctionalTestBase):
         headers = self._headers()
         for resource_type in total_resource_types:
             for namespace, rs_type in resource_type.items():
-                path = \
-                    self._url('/v2/metadefs/namespaces/%s/resource_types/%s' %
-                              (namespace, rs_type))
-                response = requests.delete(path, headers=headers)
+                path = '/v2/metadefs/namespaces/%s/resource_types/%s' % (
+                    namespace, rs_type)
+                response = self.api_delete(path, headers=headers)
                 self.assertEqual(http.NO_CONTENT, response.status_code)
 
                 # Disassociated resource type should not be exist
                 # When the specified resource type is not associated with given
                 # namespace then it returns empty list in response instead of
                 # raising not found error
-                path = self._url(
-                    '/v2/metadefs/namespaces/%s/resource_types' % namespace)
-                response = requests.get(path, headers=headers)
-                metadef_resource_type = response.json()
+                path = '/v2/metadefs/namespaces/%s/resource_types' % namespace
+                response = self.api_get(path, headers=headers)
+                metadef_resource_type = jsonutils.loads(response.text)
                 self.assertEqual(
                     [], metadef_resource_type['resource_type_associations'])
