@@ -320,7 +320,8 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
         self.assertEqual(False, enforcer.check(context, 'get_image', {}))
 
     def test_policy_file_get_image_default_everybody(self):
-        rules = {"default": ''}
+        rules = {"default": '',
+                 "get_image": ''}
         self.set_policy_rules(rules)
 
         enforcer = glance.api.policy.Enforcer(
@@ -393,29 +394,6 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
         enforcer.check(context, 'foo', {})
         mock_enforcer.assert_called_once_with('foo', {}, context)
 
-    def test_ensure_experimental_warning_is_logged_for_secure_rbac(self):
-        self.config(enforce_new_defaults=True, group='oslo_policy')
-        self.config(enforce_secure_rbac=True)
-        expected_log_string = (
-            "Deploying glance with secure RBAC personas enabled via "
-            "`glance-api.conf [DEFAULT] enforce_secure_rbac=True` and "
-            "`glance-api.conf [oslo_policy] enforce_new_defaults=True` "
-            "is marked as EXPERIMENTAL in Wallaby. The status of this "
-            "feature will graduate to SUPPORTED as glance adopts more "
-            "personas, specifically for system-scope."
-        )
-        with mock.patch.object(glance.api.policy, 'LOG') as mock_log:
-            glance.api.policy.Enforcer(
-                suppress_deprecation_warnings=True)
-            mock_log.warning.assert_called_once_with(expected_log_string)
-
-    def test_ensure_experimental_warning_is_not_logged_for_legacy_rbac(self):
-        self.config(enforce_new_defaults=False, group='oslo_policy')
-        with mock.patch.object(glance.api.policy, 'LOG') as mock_log:
-            glance.api.policy.Enforcer(
-                suppress_deprecation_warnings=True)
-            mock_log.warning.assert_not_called()
-
 
 class TestPolicyEnforcerNoFile(base.IsolatedUnitTest):
 
@@ -508,7 +486,8 @@ class TestDefaultPolicyCheckStrings(base.IsolatedUnitTest):
         self.assertEqual(expected, base_policy.PROJECT_MEMBER)
 
     def test_admin_or_project_member_check_string(self):
-        expected = 'role:admin or (role:member and project_id:%(project_id)s)'
+        expected = ('rule:context_is_admin or '
+                    '(role:member and project_id:%(project_id)s)')
         self.assertEqual(expected, base_policy.ADMIN_OR_PROJECT_MEMBER)
 
     def test_project_member_download_image_check_string(self):
@@ -528,7 +507,8 @@ class TestDefaultPolicyCheckStrings(base.IsolatedUnitTest):
         self.assertEqual(expected, base_policy.PROJECT_READER)
 
     def test_admin_or_project_reader_check_string(self):
-        expected = 'role:admin or (role:reader and project_id:%(project_id)s)'
+        expected = ('rule:context_is_admin or '
+                    '(role:reader and project_id:%(project_id)s)')
         self.assertEqual(expected, base_policy.ADMIN_OR_PROJECT_READER)
 
     def test_project_reader_get_image_check_string(self):
@@ -543,6 +523,19 @@ class TestDefaultPolicyCheckStrings(base.IsolatedUnitTest):
             PROJECT_READER_OR_IMAGE_MEMBER_OR_COMMUNITY_OR_PUBLIC_OR_SHARED
         )
 
+    def test_service_or_member_check_string(self):
+        expected = (
+            'rule:service_api or (role:member and project_id:%(project_id)s'
+            ' and project_id:%(owner)s)'
+        )
+        self.assertEqual(expected, base_policy.SERVICE_OR_PROJECT_MEMBER)
+
+    def test_service_check_string(self):
+        expected = (
+            'rule:service_api'
+        )
+        self.assertEqual(expected, base_policy.SERVICE)
+
 
 class TestImageTarget(base.IsolatedUnitTest):
     def test_image_target_ignores_locations(self):
