@@ -12,19 +12,21 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+
+import copy
+import fixtures
+from unittest import mock
+from unittest.mock import patch
 import uuid
 
-import mock
-from mock import patch
-from oslo_utils import encodeutils
+from oslo_limit import exception as ol_exc
+from oslo_limit import fixture as ol_fixture
 from oslo_utils import units
 
-# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
-from six.moves import range
-
 from glance.common import exception
 from glance.common import store_utils
 import glance.quota
+from glance.quota import keystone as ks_quota
 from glance.tests.unit import utils as unit_test_utils
 from glance.tests import utils as test_utils
 
@@ -42,7 +44,7 @@ class FakeImage(object):
     locations = [{'url': 'file:///not/a/path', 'metadata': {}}]
     tags = set([])
 
-    def set_data(self, data, size=None, backend=None):
+    def set_data(self, data, size=None, backend=None, set_active=True):
         self.size = 0
         for d in data:
             self.size += len(d)
@@ -52,6 +54,7 @@ class FakeImage(object):
 
 
 class TestImageQuota(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestImageQuota, self).setUp()
 
@@ -177,6 +180,31 @@ class TestImageQuota(test_utils.BaseTestCase):
         self._quota_exceeded_size(str(quota), data, deleted=False,
                                   size=quota - 1)
 
+    def test_quota_exceeded_keystone_quotas(self):
+        # Set our global limit to a tiny ten bytes
+        self.config(user_storage_quota='10B')
+        context = FakeContext()
+        db_api = unit_test_utils.FakeDB()
+        store_api = unit_test_utils.FakeStoreAPI()
+        store = unit_test_utils.FakeStoreUtils(store_api)
+        base_image = FakeImage()
+        base_image.image_id = 'id'
+        image = glance.quota.ImageProxy(base_image, context, db_api, store)
+
+        # With keystone quotas disabled, a 100 byte image should fail the
+        # global limit.
+        data = '*' * 100
+        self.assertRaises(exception.StorageQuotaFull,
+                          image.set_data,
+                          data,
+                          size=len(data))
+
+        # If we turn on keystone quotas, the global limit gets ignored
+        # so the same image no longer fails.
+        self.config(endpoint_id='ENDPOINT_ID', group='oslo_limit')
+        self.config(use_keystone_limits=True)
+        image.set_data(data, size=len(data))
+
     def test_append_location(self):
         new_location = {'url': 'file:///a/path', 'metadata': {},
                         'status': 'active'}
@@ -283,8 +311,8 @@ class TestImageQuota(test_utils.BaseTestCase):
         image = glance.quota.ImageProxy(base_image, context, db_api, store)
         self.assertIsNone(image.size)
 
-        self.stubs.Set(store_api, 'get_size_from_backend',
-                       unit_test_utils.fake_get_size_from_backend)
+        self.mock_object(store_api, 'get_size_from_backend',
+                         unit_test_utils.fake_get_size_from_backend)
         image.locations.append({'url': 'file:///fake.img.tar.gz',
                                 'metadata': {}})
         self.assertIn({'url': 'file:///fake.img.tar.gz', 'metadata': {}},
@@ -300,8 +328,8 @@ class TestImageQuota(test_utils.BaseTestCase):
         image = glance.quota.ImageProxy(base_image, context, db_api, store)
         self.assertIsNone(image.size)
 
-        self.stubs.Set(store_api, 'get_size_from_backend',
-                       unit_test_utils.fake_get_size_from_backend)
+        self.mock_object(store_api, 'get_size_from_backend',
+                         unit_test_utils.fake_get_size_from_backend)
         image.locations.insert(0,
                                {'url': 'file:///fake.img.tar.gz',
                                 'metadata': {}})
@@ -318,8 +346,8 @@ class TestImageQuota(test_utils.BaseTestCase):
         image = glance.quota.ImageProxy(base_image, context, db_api, store)
         self.assertIsNone(image.size)
 
-        self.stubs.Set(store_api, 'get_size_from_backend',
-                       unit_test_utils.fake_get_size_from_backend)
+        self.mock_object(store_api, 'get_size_from_backend',
+                         unit_test_utils.fake_get_size_from_backend)
         image.locations = [{'url': 'file:///fake.img.tar.gz', 'metadata': {}}]
         self.assertEqual([{'url': 'file:///fake.img.tar.gz', 'metadata': {}}],
                          image.locations)
@@ -334,14 +362,15 @@ class TestImageQuota(test_utils.BaseTestCase):
         image = glance.quota.ImageProxy(base_image, context, db_api, store)
         self.assertIsNone(image.size)
 
-        self.stubs.Set(store_api, 'get_size_from_backend',
-                       unit_test_utils.fake_get_size_from_backend)
+        self.mock_object(store_api, 'get_size_from_backend',
+                         unit_test_utils.fake_get_size_from_backend)
         image.locations += [{'url': 'file:///fake.img.tar.gz', 'metadata': {}}]
         self.assertIn({'url': 'file:///fake.img.tar.gz', 'metadata': {}},
                       image.locations)
 
 
 class TestImagePropertyQuotas(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestImagePropertyQuotas, self).setUp()
         self.base_image = FakeImage()
@@ -375,8 +404,7 @@ class TestImagePropertyQuotas(test_utils.BaseTestCase):
         self.image.extra_properties = {'foo': 'bar', 'foo2': 'bar2'}
         exc = self.assertRaises(exception.ImagePropertyLimitExceeded,
                                 self.image_repo_proxy.save, self.image)
-        self.assertIn("Attempted: 2, Maximum: 1",
-                      encodeutils.exception_to_unicode(exc))
+        self.assertIn("Attempted: 2, Maximum: 1", str(exc))
 
     def test_save_image_unlimited_image_properties(self):
         self.config(image_property_quota=-1)
@@ -401,8 +429,7 @@ class TestImagePropertyQuotas(test_utils.BaseTestCase):
         self.image.extra_properties = {'foo': 'bar', 'foo2': 'bar2'}
         exc = self.assertRaises(exception.ImagePropertyLimitExceeded,
                                 self.image_repo_proxy.add, self.image)
-        self.assertIn("Attempted: 2, Maximum: 1",
-                      encodeutils.exception_to_unicode(exc))
+        self.assertIn("Attempted: 2, Maximum: 1", str(exc))
 
     def test_add_image_unlimited_image_properties(self):
         self.config(image_property_quota=-1)
@@ -485,6 +512,7 @@ class TestImagePropertyQuotas(test_utils.BaseTestCase):
 
 
 class TestImageTagQuotas(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestImageTagQuotas, self).setUp()
         self.base_image = mock.Mock()
@@ -512,8 +540,7 @@ class TestImageTagQuotas(test_utils.BaseTestCase):
 
         exc = self.assertRaises(exception.ImageTagLimitExceeded,
                                 setattr, self.image, 'tags', ['foo', 'bar'])
-        self.assertIn('Attempted: 2, Maximum: 0',
-                      encodeutils.exception_to_unicode(exc))
+        self.assertIn('Attempted: 2, Maximum: 0', str(exc))
         self.assertEqual(0, len(self.image.tags))
 
     def test_replace_unlimited_image_tags(self):
@@ -531,8 +558,7 @@ class TestImageTagQuotas(test_utils.BaseTestCase):
         self.image.tags.add('foo')
         exc = self.assertRaises(exception.ImageTagLimitExceeded,
                                 self.image.tags.add, 'bar')
-        self.assertIn('Attempted: 2, Maximum: 1',
-                      encodeutils.exception_to_unicode(exc))
+        self.assertIn('Attempted: 2, Maximum: 1', str(exc))
 
     def test_add_unlimited_image_tags(self):
         self.config(image_tag_quota=-1)
@@ -549,6 +575,7 @@ class TestImageTagQuotas(test_utils.BaseTestCase):
 
 
 class TestQuotaImageTagsProxy(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestQuotaImageTagsProxy, self).setUp()
 
@@ -562,8 +589,7 @@ class TestQuotaImageTagsProxy(test_utils.BaseTestCase):
         proxy = glance.quota.QuotaImageTagsProxy(set([]))
         exc = self.assertRaises(exception.ImageTagLimitExceeded,
                                 proxy.add, 'bar')
-        self.assertIn('Attempted: 1, Maximum: 0',
-                      encodeutils.exception_to_unicode(exc))
+        self.assertIn('Attempted: 1, Maximum: 0', str(exc))
 
     def test_equals(self):
         proxy = glance.quota.QuotaImageTagsProxy(set([]))
@@ -592,8 +618,28 @@ class TestQuotaImageTagsProxy(test_utils.BaseTestCase):
             items.remove(item)
         self.assertEqual(0, len(items))
 
+    def test_tags_attr_no_loop(self):
+        proxy = glance.quota.QuotaImageTagsProxy(None)
+        self.assertEqual(set([]), proxy.tags)
+
+    def test_tags_deepcopy(self):
+        proxy = glance.quota.QuotaImageTagsProxy(set(['a', 'b']))
+        proxy_copy = copy.deepcopy(proxy)
+        self.assertEqual(set(['a', 'b']), proxy_copy.tags)
+        self.assertIn('a', proxy_copy)
+        # remove is a found via __getattr__
+        proxy_copy.remove('a')
+        self.assertNotIn('a', proxy_copy)
+
+    def test_tags_delete(self):
+        proxy = glance.quota.QuotaImageTagsProxy(set(['a', 'b']))
+        self.assertEqual(set(['a', 'b']), proxy.tags)
+        del proxy.tags
+        self.assertIsNone(proxy.tags)
+
 
 class TestImageMemberQuotas(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestImageMemberQuotas, self).setUp()
         db_api = unit_test_utils.FakeDB()
@@ -631,6 +677,7 @@ class TestImageMemberQuotas(test_utils.BaseTestCase):
 
 
 class TestImageLocationQuotas(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestImageLocationQuotas, self).setUp()
         self.base_image = mock.Mock()
@@ -668,8 +715,7 @@ class TestImageLocationQuotas(test_utils.BaseTestCase):
         ]
         exc = self.assertRaises(exception.ImageLocationLimitExceeded,
                                 setattr, self.image, 'locations', locations)
-        self.assertIn('Attempted: 3, Maximum: 1',
-                      encodeutils.exception_to_unicode(exc))
+        self.assertIn('Attempted: 3, Maximum: 1', str(exc))
         self.assertEqual(1, len(self.image.locations))
 
     def test_replace_unlimited_image_locations(self):
@@ -692,8 +738,7 @@ class TestImageLocationQuotas(test_utils.BaseTestCase):
         location2 = {"url": "file:///fake2.img.tar.gz", "metadata": {}}
         exc = self.assertRaises(exception.ImageLocationLimitExceeded,
                                 self.image.locations.append, location2)
-        self.assertIn('Attempted: 2, Maximum: 1',
-                      encodeutils.exception_to_unicode(exc))
+        self.assertIn('Attempted: 2, Maximum: 1', str(exc))
 
     def test_add_unlimited_image_locations(self):
         self.config(image_location_quota=-1)
@@ -709,3 +754,145 @@ class TestImageLocationQuotas(test_utils.BaseTestCase):
         self.config(image_location_quota=0)
         self.image.locations.remove(location1)
         self.assertEqual(0, len(self.image.locations))
+
+
+class TestImageKeystoneQuota(test_utils.BaseTestCase):
+    def setUp(self):
+        super(TestImageKeystoneQuota, self).setUp()
+
+        reglimits = {
+            ks_quota.QUOTA_IMAGE_SIZE_TOTAL: 500,
+            'another_limit': 2,
+        }
+        ksqf = ol_fixture.LimitFixture(reglimits, {})
+
+        self.useFixture(ksqf)
+
+        self.db_api = unit_test_utils.FakeDB()
+        self.useFixture(fixtures.MockPatch('glance.quota.keystone.db',
+                                           self.db_api))
+
+    def _create_fake_image(self, context, size):
+        location_count = 2
+        locations = []
+        for i in range(location_count):
+            locations.append({'url': 'file:///g/there/it/is%d' % i,
+                              'status': 'active',
+                              'metadata': {}})
+        image_values = {'id': str(uuid.uuid4()), 'owner': context.owner,
+                        'status': 'active', 'size': size * units.Mi,
+                        'locations': locations}
+        self.db_api.image_create(context, image_values)
+
+    def test_enforce_overquota(self):
+        # Check that a single large image with multiple locations will
+        # trip the quota check.
+        self.config(endpoint_id='ENDPOINT_ID', group='oslo_limit')
+        self.config(use_keystone_limits=True)
+        context = FakeContext()
+        self._create_fake_image(context, 300)
+        exc = self.assertRaises(exception.LimitExceeded,
+                                ks_quota.enforce_image_size_total,
+                                context, context.owner)
+        self.assertIn('image_size_total is over limit of 500', str(exc))
+
+    def test_enforce_overquota_with_delta(self):
+        # Check that delta is honored, if used.
+        self.config(endpoint_id='ENDPOINT_ID', group='oslo_limit')
+        self.config(use_keystone_limits=True)
+        context = FakeContext()
+        self._create_fake_image(context, 200)
+        ks_quota.enforce_image_size_total(context, context.owner)
+        ks_quota.enforce_image_size_total(context, context.owner,
+                                          delta=50)
+        self.assertRaises(exception.LimitExceeded,
+                          ks_quota.enforce_image_size_total,
+                          context, context.owner, delta=200)
+
+    def test_enforce_overquota_disabled(self):
+        # Just like the overquota case above, but without being enabled,
+        # so no failure
+        self.config(endpoint_id='ENDPOINT_ID', group='oslo_limit')
+        self.config(use_keystone_limits=False)
+        context = FakeContext()
+        self._create_fake_image(context, 300)
+        # Does not raise because keystone limits are disabled
+        ks_quota.enforce_image_size_total(context, context.owner)
+
+    def test_enforce_overquota_multiple(self):
+        # Check that multiple images with a combined amount
+        # (2*2*150=600) over the quota will trip the quota check.
+        self.config(endpoint_id='ENDPOINT_ID', group='oslo_limit')
+        self.config(use_keystone_limits=True)
+        context = FakeContext()
+        self._create_fake_image(context, 150)
+        self._create_fake_image(context, 150)
+        exc = self.assertRaises(exception.LimitExceeded,
+                                ks_quota.enforce_image_size_total,
+                                context, context.owner)
+        self.assertIn('image_size_total is over limit of 500', str(exc))
+
+    def test_enforce_underquota(self):
+        self.config(endpoint_id='ENDPOINT_ID', group='oslo_limit')
+        self.config(use_keystone_limits=True)
+        context = FakeContext()
+        self._create_fake_image(context, 100)
+        # We are under quota, so no exception expected
+        ks_quota.enforce_image_size_total(context, context.owner)
+
+    def test_enforce_underquota_with_others_over_quota(self):
+        self.config(endpoint_id='ENDPOINT_ID', group='oslo_limit')
+        self.config(use_keystone_limits=True)
+        # Put the first tenant over quota
+        context = FakeContext()
+        self._create_fake_image(context, 300)
+        self._create_fake_image(context, 300)
+
+        # Create an image for another tenant that is not over quota
+        other_context = FakeContext()
+        other_context.owner = 'someone_else'
+        self._create_fake_image(other_context, 100)
+        # This tenant should pass the quota check, because it is under quota,
+        # even though the other is over.
+        ks_quota.enforce_image_size_total(other_context, other_context.owner)
+
+    def test_enforce_multiple_limits_under_quota(self):
+        self.config(endpoint_id='ENDPOINT_ID', group='oslo_limit')
+        self.config(use_keystone_limits=True)
+        context = FakeContext()
+        # Make sure that we can call the multi-limit handler and pass when
+        # we are under quota.
+        ks_quota._enforce_some(context, context.owner,
+                               {ks_quota.QUOTA_IMAGE_SIZE_TOTAL: lambda: 200,
+                                'another_limit': lambda: 1},
+                               {'another_limit': 1})
+
+    def test_enforce_multiple_limits_over_quota(self):
+        self.config(endpoint_id='ENDPOINT_ID', group='oslo_limit')
+        self.config(use_keystone_limits=True)
+        context = FakeContext()
+        # Make sure that even if one of a multi-limit call is over
+        # quota, we get the exception.
+        self.assertRaises(exception.LimitExceeded,
+                          ks_quota._enforce_some,
+                          context, context.owner,
+                          {ks_quota.QUOTA_IMAGE_SIZE_TOTAL: lambda: 200,
+                           'another_limit': lambda: 1},
+                          {'another_limit': 5})
+
+    @mock.patch('oslo_limit.limit.Enforcer')
+    @mock.patch.object(ks_quota, 'LOG')
+    def test_oslo_limit_config_fail(self, mock_LOG, mock_enforcer):
+        self.config(endpoint_id='ENDPOINT_ID', group='oslo_limit')
+        self.config(use_keystone_limits=True)
+        mock_enforcer.return_value.enforce.side_effect = (
+            ol_exc.SessionInitError('test'))
+        context = FakeContext()
+        self._create_fake_image(context, 100)
+        self.assertRaises(ol_exc.SessionInitError,
+                          ks_quota.enforce_image_size_total,
+                          context, context.owner)
+        mock_LOG.error.assert_called_once_with(
+            'Failed to initialize oslo_limit, likely due to '
+            'incorrect or insufficient configuration: %(err)s',
+            {'err': "Can't initialise OpenStackSDK session: test."})
