@@ -142,7 +142,8 @@ class APIImagePolicy(APIPolicyBase):
                                                       mock.ANY)
 
     def test_delete_locations_falls_back_to_legacy(self):
-        self.config(enforce_secure_rbac=False)
+        self.config(enforce_new_defaults=False, group='oslo_policy')
+        self.config(enforce_scope=False, group='oslo_policy')
 
         # As admin, image is mutable even if owner does not match
         self.context.is_admin = True
@@ -166,8 +167,10 @@ class APIImagePolicy(APIPolicyBase):
             self.policy.delete_locations()
             m.assert_called_once_with(self.context, self.image)
 
-        # Make sure we are not checking it if enforce_secure_rbac=True
-        self.config(enforce_secure_rbac=True)
+        # Make sure we are not checking it if enforce_new_defaults=True and
+        # enforce_scope=True
+        self.config(enforce_new_defaults=True, group='oslo_policy')
+        self.config(enforce_scope=True, group='oslo_policy')
         with mock.patch('glance.api.v2.policy.check_is_image_mutable') as m:
             self.policy.delete_locations()
             self.assertFalse(m.called)
@@ -235,7 +238,8 @@ class APIImagePolicy(APIPolicyBase):
                                                       generic_target)
 
     def test_add_image_falls_back_to_legacy(self):
-        self.config(enforce_secure_rbac=False)
+        self.config(enforce_new_defaults=False, group='oslo_policy')
+        self.config(enforce_scope=False, group='oslo_policy')
 
         self.context.is_admin = False
         self.policy = policy.ImageAPIPolicy(self.context, {'owner': 'else'},
@@ -252,7 +256,8 @@ class APIImagePolicy(APIPolicyBase):
         # Make sure we are not calling the legacy handler if
         # secure_rbac is being used. We won't fail the check because
         # our enforcer is a mock, just make sure we don't call that handler.
-        self.config(enforce_secure_rbac=True)
+        self.config(enforce_new_defaults=True, group='oslo_policy')
+        self.config(enforce_scope=True, group='oslo_policy')
         with mock.patch('glance.api.v2.policy.check_admin_or_same_owner') as m:
             self.policy.add_image()
             m.assert_not_called()
@@ -287,8 +292,8 @@ class APIImagePolicy(APIPolicyBase):
                                                       mock.ANY)
 
     def test_delete_image_falls_back_to_legacy(self):
-        self.config(enforce_secure_rbac=False)
-
+        self.config(enforce_new_defaults=False, group='oslo_policy')
+        self.config(enforce_scope=False, group='oslo_policy')
         # As admin, image is mutable even if owner does not match
         self.context.is_admin = True
         self.context.owner = 'someuser'
@@ -311,8 +316,10 @@ class APIImagePolicy(APIPolicyBase):
             self.policy.delete_image()
             m.assert_called_once_with(self.context, self.image)
 
-        # Make sure we are not checking it if enforce_secure_rbac=True
-        self.config(enforce_secure_rbac=True)
+        # Make sure we are not checking it if enforce_new_defaults=True and
+        # enforce_scope=True
+        self.config(enforce_new_defaults=True, group='oslo_policy')
+        self.config(enforce_scope=True, group='oslo_policy')
         with mock.patch('glance.api.v2.policy.check_is_image_mutable') as m:
             self.policy.delete_image()
             self.assertFalse(m.called)
@@ -324,7 +331,8 @@ class APIImagePolicy(APIPolicyBase):
                                                       mock.ANY)
 
     def test_upload_image_falls_back_to_legacy(self):
-        self.config(enforce_secure_rbac=False)
+        self.config(enforce_new_defaults=False, group='oslo_policy')
+        self.config(enforce_scope=False, group='oslo_policy')
 
         # As admin, image is mutable even if owner does not match
         self.context.is_admin = True
@@ -348,8 +356,10 @@ class APIImagePolicy(APIPolicyBase):
             self.policy.upload_image()
             m.assert_called_once_with(self.context, self.image)
 
-        # Make sure we are not checking it if enforce_secure_rbac=True
-        self.config(enforce_secure_rbac=True)
+        # Make sure we are not checking it if enforce_new_defaults=True and
+        # enforce_scope=True
+        self.config(enforce_new_defaults=True, group='oslo_policy')
+        self.config(enforce_scope=True, group='oslo_policy')
         with mock.patch('glance.api.v2.policy.check_is_image_mutable') as m:
             self.policy.upload_image()
             self.assertFalse(m.called)
@@ -367,7 +377,8 @@ class APIImagePolicy(APIPolicyBase):
                                                       mock.ANY)
 
     def test_modify_image_falls_back_to_legacy(self):
-        self.config(enforce_secure_rbac=False)
+        self.config(enforce_new_defaults=False, group='oslo_policy')
+        self.config(enforce_scope=False, group='oslo_policy')
 
         # As admin, image is mutable even if owner does not match
         self.context.is_admin = True
@@ -391,8 +402,10 @@ class APIImagePolicy(APIPolicyBase):
             self.policy.modify_image()
             m.assert_called_once_with(self.context, self.image)
 
-        # Make sure we are not checking it if enforce_secure_rbac=True
-        self.config(enforce_secure_rbac=True)
+        # Make sure we are not checking it if enforce_new_defaults=True and
+        # enforce_scope=True
+        self.config(enforce_new_defaults=True, group='oslo_policy')
+        self.config(enforce_scope=True, group='oslo_policy')
         with mock.patch('glance.api.v2.policy.check_is_image_mutable') as m:
             self.policy.modify_image()
             self.assertFalse(m.called)
@@ -404,7 +417,8 @@ class APIImagePolicy(APIPolicyBase):
                                                       mock.ANY)
 
     def test_deactivate_image_falls_back_to_legacy(self):
-        self.config(enforce_secure_rbac=False)
+        self.config(enforce_new_defaults=False, group='oslo_policy')
+        self.config(enforce_scope=False, group='oslo_policy')
 
         # As admin, image is mutable even if owner does not match
         self.context.is_admin = True
@@ -428,8 +442,10 @@ class APIImagePolicy(APIPolicyBase):
             self.policy.deactivate_image()
             m.assert_called_once_with(self.context, self.image)
 
-        # Make sure we are not checking it if enforce_secure_rbac=True
-        self.config(enforce_secure_rbac=True)
+        # Make sure we are not checking it if enforce_new_defaults=Truei and
+        # enforce_scope=True
+        self.config(enforce_new_defaults=True, group='oslo_policy')
+        self.config(enforce_scope=True, group='oslo_policy')
         with mock.patch('glance.api.v2.policy.check_is_image_mutable') as m:
             self.policy.deactivate_image()
             self.assertFalse(m.called)
@@ -441,7 +457,8 @@ class APIImagePolicy(APIPolicyBase):
                                                       mock.ANY)
 
     def test_reactivate_image_falls_back_to_legacy(self):
-        self.config(enforce_secure_rbac=False)
+        self.config(enforce_new_defaults=False, group='oslo_policy')
+        self.config(enforce_scope=False, group='oslo_policy')
 
         # As admin, image is mutable even if owner does not match
         self.context.is_admin = True
@@ -465,8 +482,10 @@ class APIImagePolicy(APIPolicyBase):
             self.policy.reactivate_image()
             m.assert_called_once_with(self.context, self.image)
 
-        # Make sure we are not checking it if enforce_secure_rbac=True
-        self.config(enforce_secure_rbac=True)
+        # Make sure we are not checking it if enforce_new_defaults=True and
+        # enforce_scope=True
+        self.config(enforce_new_defaults=True, group='oslo_policy')
+        self.config(enforce_scope=True, group='oslo_policy')
         with mock.patch('glance.api.v2.policy.check_is_image_mutable') as m:
             self.policy.reactivate_image()
             self.assertFalse(m.called)
